@@ -3,15 +3,15 @@ __author__ = 'Imam Hossain Roni'
 __copyright__ = "Copyright 2021, Roni"
 __credits__ = ["Roni"]
 __license__ = "MIT"
-__version__ = "1.0.2"
+__version__ = "1.0.3"
 __maintainer__ = "Roni"
 __email__ = "imamhossainroni95@gmail.com"
 __status__ = "Development"
 
-from enum import Enum
+from enum import IntEnum
 
 
-class Choice(Enum):
+class Choice(IntEnum):
     def __init__(self, *args):
         cls = self.__class__
         if any(self.value == e.value for e in cls):
